@@ -57,7 +57,7 @@ def plot_mesh_res(adjusted_mesh: dict, save_plot: bool, mesh_res_file_name: str,
     num_of_points = str(idx)
     axs[0].set_title(title + ", n = " + num_of_points, y=1.3)  # add it to the title
     # plot the legacy mesh
-    axs[0].plot(xvals, yvals, label="Legacy mesh")
+    axs[0].plot(xvals, yvals, label="Final mesh")
     # plot the mesh ratio
     axs[1].plot(xvals, rvals, label='Ratio')
     axs[1].set_title("Ratio", y=1.3)
@@ -68,7 +68,7 @@ def plot_mesh_res(adjusted_mesh: dict, save_plot: bool, mesh_res_file_name: str,
         for segments in adjusted_mesh['segment_list']:
             s1 = segments['s1'] + (adjusted_mesh['phi_shift'])
             s0 = segments['s0'] + (adjusted_mesh['phi_shift'])
-            axs[0].hlines(max(segments['ds0'], segments['ds1']), s0, s1, linewidth=3, label=seg_label)
+            axs[0].hlines(max(segments['ds0'], segments['ds1']), s0, s1, linewidth=3, color='k', label=seg_label)
             seg_label = "_nolegend_"
             axs[i].axvline(x=s1, dashes=[6, 2], color='gray')
             axs[i].axvline(x=s0, dashes=[6, 2], color='gray')
