@@ -42,6 +42,7 @@ class MeshApp:
         width_screen_pxl = root.winfo_screenwidth()
         height_screen_mm = root.winfo_screenmmheight()
         height_screen_pxl = root.winfo_screenheight()
+        self.hdf_file_path = hdf_file_path
 
         for ii in range(3):
             root.grid_columnconfigure(ii, weight=1)  # the text and entry frames column
@@ -57,17 +58,16 @@ class MeshApp:
         self.leftFrame.grid(row=0, column=0, sticky=tk.NSEW,  rowspan=2)
 
         # label with step 1 instruction
-        tk.Label(self.leftFrame, text="Step 1: Draw a box, when box is finalized click submit box button.").\
+        tk.Label(self.leftFrame, text="Step 1: Draw each box, when box is finalized click save latest box button.").\
             grid(row=0, column=0, columnspan=5, sticky=tk.NW, pady=10)
 
         # save latest box button
-        tk.Button(self.leftFrame, text='Save latest box', activeforeground='navy',
+        tk.Button(self.leftFrame, text='save latest box', activeforeground='navy',
                   command=self.save_latest_box).grid(row=1, column=1, pady=10)
 
         # reset latest box button
-        tk.Label(self.leftFrame, text="Remove all boxes:").grid(row=2, column=0, sticky=tk.E)
         tk.Button(self.leftFrame, text='Reset', activeforeground='navy', command=self.reset) \
-            .grid(row=2, column=1, pady=10)
+            .grid(row=4, column=1, pady=10)
 
         # delete drop-box
         tk.Label(self.leftFrame, text="Remove box #:").grid(row=3, column=0, sticky=tk.E)
@@ -79,15 +79,15 @@ class MeshApp:
         tk.Button(self.leftFrame, text='apply', command=self.delete_box).grid(row=3, column=2, sticky=tk.W)
 
         # redraw drop-box
-        tk.Label(self.leftFrame, text="Redraw box #:").grid(row=4, column=0, sticky=tk.E)
+        tk.Label(self.leftFrame, text="Redraw box #:").grid(row=2, column=0, sticky=tk.E)
         self.redraw_variable = tk.StringVar(self.leftFrame)
         self.redraw_variable.set(' ')
         self.redraw_opt = tk.OptionMenu(self.leftFrame, self.redraw_variable, ' ')
-        self.redraw_opt.grid(row=4, column=1, sticky=tk.NSEW)
+        self.redraw_opt.grid(row=2, column=1, sticky=tk.NSEW)
         self.del_tb_variable.trace("w", self.redraw_drop_box_get_val)
 
-        tk.Button(self.leftFrame, text='apply', command=self.redraw_box_apply).grid(row=4, column=2, sticky=tk.W)
-        tk.Button(self.leftFrame, text='submit', command=self.redraw_submit).grid(row=4, column=3, sticky=tk.W)
+        tk.Button(self.leftFrame, text='apply', command=self.redraw_box_apply).grid(row=2, column=2, sticky=tk.W)
+        tk.Button(self.leftFrame, text='submit', command=self.redraw_submit).grid(row=2, column=2, sticky=tk.E)
 
         # optional edit box table manually in a new window.
         tk.Label(self.leftFrame, text="(Optional) Enter box coordinates manually").grid(row=5, column=0,
@@ -98,28 +98,29 @@ class MeshApp:
         # step 2- enter ds values
         tk.Label(self.leftFrame, text="Step 2: After submitting each box indicate desired ds in textbox below.")\
             .grid(row=7, column=0, columnspan=7, sticky=tk.W, pady=10)
-        tk.Label(self.leftFrame, text="ds", relief=tk.RIDGE, bg='lightgray', bd=2). \
-            grid(row=8, column=1, sticky=tk.NSEW)
-        tk.Label(self.leftFrame, text="ratio", relief=tk.RIDGE, bg='lightgray', bd=2). \
-            grid(row=8, column=2, sticky=tk.NSEW, columnspan=2)
+
+        # enter BG ratio
+        tk.Label(self.leftFrame, text="BG ratio:").grid(row=8, column=0, sticky=tk.E, pady=10)
+        self.bg_ratio = tk.Entry(self.leftFrame, width=5)
+        self.bg_ratio.insert(tk.END, '1.06')
+        self.bg_ratio.grid(row=8, column=1, sticky=tk.W)
+
+        # enter FG ratio
+        tk.Label(self.leftFrame, text="FG ratio:").grid(row=8, column=2, sticky=tk.E, pady=10)
+        self.fg_ratio = tk.Entry(self.leftFrame, width=5)
+        self.fg_ratio.insert(tk.END, '1.03')
+        self.fg_ratio.grid(row=8, column=3, sticky=tk.W)
+
+        tk.Label(self.leftFrame, text="ds", relief=tk.RIDGE, bg='lightgray', bd=2, width=10). \
+            grid(row=9, column=1, sticky=tk.NSEW)
+        tk.Label(self.leftFrame, text="ratio", relief=tk.RIDGE, bg='lightgray', bd=2, width=10). \
+            grid(row=9, column=2, sticky=tk.NSEW)
 
         # second frame: includes step 3, 4 and building a radial mesh manually.
         self.rightFrame = VerticalScrolledFrame(root, relief=tk.SUNKEN, width=width_screen_pxl/4,
-                                                height=height_screen_pxl/5) # width=465, height=600, borderwidth=2,
+                                                height=height_screen_pxl/5)
         self.rightFrame.grid(row=0, column=2, rowspan=2, sticky=tk.NSEW)
 
-        # step 3- enter BG ratio
-        tk.Label(self.rightFrame, text="Step 3: Input BG ratio:").grid(row=0, column=0, sticky=tk.W, pady=10)
-        self.bg_ratio = tk.Entry(self.rightFrame, width=5)
-        self.bg_ratio.insert(tk.END, '1.06')
-        self.bg_ratio.grid(row=0, column=1, sticky=tk.W)
-
-        # enter FG ratio
-        tk.Label(self.rightFrame, text="Input FG ratio:").grid(row=0, column=2, sticky=tk.E, pady=10, columnspan=2)
-        self.fg_ratio = tk.Entry(self.rightFrame, width=5)
-        self.fg_ratio.insert(tk.END, '1.03')
-        self.fg_ratio.grid(row=0, column=4, sticky=tk.W)
-
         # step 4- get total number of points in theta and phi
         tk.Button(self.rightFrame, text='\u03B8 number of points', command=self.num_points_theta) \
             .grid(row=2, column=0, columnspan=1, pady=10)
@@ -130,15 +131,15 @@ class MeshApp:
         tk.Label(self.rightFrame, text="     ").grid(row=3, column=1, pady=10, sticky=tk.W)
 
         # step 4- get plots of phi and theta mesh results
-        tk.Label(self.rightFrame, text="Step 4: Get mesh results").grid(row=1, column=0, sticky=tk.W,
+        tk.Label(self.rightFrame, text="Step 3: Get mesh results").grid(row=1, column=0, sticky=tk.W,
                                                                                 pady=10)
-        tk.Button(self.rightFrame, text='\u03B8 mesh results', command=self.get_theta_results). \
+        tk.Button(self.rightFrame, text='\u03B8 mesh plot', command=self.get_theta_results). \
             grid(row=2, column=2, sticky=tk.W, columnspan=2, pady=10)
-        tk.Button(self.rightFrame, text='\u03C6 mesh results', command=self.get_phi_results). \
+        tk.Button(self.rightFrame, text='\u03C6 mesh plot', command=self.get_phi_results). \
             grid(row=3, column=2, sticky=tk.W, columnspan=2, pady=10)
 
         # step 5- radial mesh table
-        tk.Label(self.rightFrame, text="Step 5: Input radial mesh segments").grid(row=4, column=0,
+        tk.Label(self.rightFrame, text="Step 4: Input radial mesh segments").grid(row=4, column=0,
                                                                                           columnspan=2, pady=10,
                                                                                           sticky=tk.W)
         # get radial total number of mesh points
@@ -147,7 +148,7 @@ class MeshApp:
         tk.Label(self.rightFrame, text="     ").grid(row=5, column=1, pady=10, sticky=tk.W)
 
         # get radial mesh resulted plot
-        tk.Button(self.rightFrame, text='r mesh results', command=self.get_radial_results). \
+        tk.Button(self.rightFrame, text='r mesh plot', command=self.get_radial_results). \
             grid(row=5, column=2, sticky=tk.W, columnspan=2, pady=10)
 
         # total number of points of all mesh (t x p x r):
@@ -158,25 +159,25 @@ class MeshApp:
 
         # RADIAL_BG_TEXTBOX
         tk.Label(self.rightFrame, text="Radial BG ratio:").grid(row=7, column=0, sticky=tk.E)
-        self.radial_bg_ratio = tk.Entry(self.rightFrame, width=5)
+        self.radial_bg_ratio = tk.Entry(self.rightFrame, width=5, bg='white')
         self.radial_bg_ratio.insert(tk.END, '1.06')
         self.radial_bg_ratio.grid(row=7, column=1, sticky=tk.W)
 
         # RADIAL_FG_TEXTBOX
         tk.Label(self.rightFrame, text="Radial FG ratio:").grid(row=7, column=2, sticky=tk.E, columnspan=2)
-        self.radial_fg_ratio = tk.Entry(self.rightFrame, width=5)
+        self.radial_fg_ratio = tk.Entry(self.rightFrame, width=5, bg='white')
         self.radial_fg_ratio.insert(tk.END, '1.03')
         self.radial_fg_ratio.grid(row=7, column=4, sticky=tk.W)
 
         # R0_TEXTBOX
         tk.Label(self.rightFrame, text="rMin:").grid(row=8, column=0, sticky=tk.E)
-        self.rMin = tk.Entry(self.rightFrame, width=5)
+        self.rMin = tk.Entry(self.rightFrame, width=5, bg='white')
         self.rMin.insert(tk.END, '1')
         self.rMin.grid(row=8, column=1, sticky=tk.W)
 
         # R1_TEXTBOX
         tk.Label(self.rightFrame, text="rMax:").grid(row=9, column=0, sticky=tk.E)
-        self.rMax = tk.Entry(self.rightFrame, width=5)
+        self.rMax = tk.Entry(self.rightFrame, width=5, bg='white')
         self.rMax.insert(tk.END, '2.5')
         self.rMax.grid(row=9, column=1, sticky=tk.W)
 
@@ -187,7 +188,7 @@ class MeshApp:
         tk.Label(self.rightFrame, text='r1', relief=tk.RIDGE, bg='lightgray', bd=2, width=6).grid(row=10, column=2,
                                                                                                   sticky=tk.NSEW,
                                                                                                   columnspan=1)
-        tk.Label(self.rightFrame, text='ds', relief=tk.RIDGE, bg='lightgray', bd=2, width=6).grid(row=10, column=3,
+        tk.Label(self.rightFrame, text='dr', relief=tk.RIDGE, bg='lightgray', bd=2, width=6).grid(row=10, column=3,
                                                                                                   sticky=tk.NSEW,
                                                                                                   columnspan=1)
         tk.Label(self.rightFrame, text='ratio', relief=tk.RIDGE, bg='lightgray', bd=2, width=9).grid(row=10,
@@ -226,12 +227,13 @@ class MeshApp:
         # save ui_session button.
         self.bottomFrame = tk.Frame(root) # width=1830, height=10
         self.bottomFrame.grid(row=2, column=1, columnspan=1)
-        tk.Button(self.bottomFrame, text="Save session", command=self.save_ui_session).grid(row=0, column=1)
-        tk.Label(self.bottomFrame, text="vmin/vmax:").grid(row=0, column=9)
+        tk.Label(self.bottomFrame, text="Step #5: Save all mesh files:").grid(row=1, column=0, columnspan=2)
+        tk.Button(self.bottomFrame, text="Save session", command=self.save_ui_session).grid(row=1, column=2)
+        tk.Label(self.bottomFrame, text="Colorbar min/max:").grid(row=0, column=0)
         self.cmax_value = tk.Entry(self.bottomFrame, width=5)
         self.cmax_value.insert(tk.END, str(abs(cmin)))
-        self.cmax_value.grid(row=0, column=10, sticky=tk.W)
-        tk.Button(self.bottomFrame, text="apply", command=self.apply_new_scale).grid(row=0, column=11)
+        self.cmax_value.grid(row=0, column=1, sticky=tk.W)
+        tk.Button(self.bottomFrame, text="apply", command=self.apply_new_scale).grid(row=0, column=2)
 
         self.canvas = FigureCanvasTkAgg(self.fig, master=self.midFrame)
         self.canvas.draw()
@@ -301,16 +303,16 @@ class MeshApp:
 
             # ds text box
             tk.Label(self.leftFrame, text=label_box, relief=tk.RIDGE, bg='lightgray', bd=2). \
-                grid(row=8 + i, column=0, sticky=tk.NSEW)
-            self.ds_tab_array.append(tk.Entry(self.leftFrame, width=11, bg='white'))
-            self.var_ds_tab_array.append(tk.Entry(self.leftFrame, width=11, bg='white'))
+                grid(row=9 + i, column=0, sticky=tk.NSEW)
+            self.ds_tab_array.append(tk.Entry(self.leftFrame, width=10, bg='white'))
+            self.var_ds_tab_array.append(tk.Entry(self.leftFrame, width=10, bg='white'))
             self.ds_tab_array[-1].insert(tk.END, str(rect.ds))
             if rect.tp_var_ds is not None:
                 self.var_ds_tab_array[-1].insert(tk.END, str(rect.tp_var_ds))
             else:
-                self.var_ds_tab_array[-1].insert(tk.END, '')
-            self.ds_tab_array[-1].grid(row=8 + i, column=1, sticky=tk.NSEW)
-            self.var_ds_tab_array[-1].grid(row=8 + i, column=2, sticky=tk.NSEW, columnspan=2)
+                self.var_ds_tab_array[-1].insert(tk.END, str(self.ui_session.FG_RATIO))
+            self.ds_tab_array[-1].grid(row=9 + i, column=1, sticky=tk.NSEW)
+            self.var_ds_tab_array[-1].grid(row=9 + i, column=2, sticky=tk.NSEW)
 
             # add r table with textbox
             tk.Label(self.rightFrame, text=label_box, relief=tk.RIDGE, bg='lightgray', bd=2) \
@@ -365,13 +367,13 @@ class MeshApp:
         """ delete all the boxes drawn on matplotlib figure and clear ui_session box_list."""
         for i in range(0, len(self.ui_session.box_list)):
             # delete the lastest ds textbox and label
-            tk.Label(self.leftFrame, text="             ").grid(row=9 + i,
+            tk.Label(self.leftFrame, text="             ").grid(row=10 + i,
                                                                 column=0, sticky=tk.NSEW)
             self.ds_tab_array[i].destroy()
             self.var_ds_tab_array[i].destroy()
 
             # delete box label in radial table
-            tk.Label(self.rightFrame, text="       ", bg='gray92', bd=2).grid(row=11 + i, column=0, sticky=tk.NSEW)
+            tk.Label(self.rightFrame, text="       ", bd=2).grid(row=11 + i, column=0, sticky=tk.NSEW)
 
         # delete the entry boxes in radial table
         for row in self.radial_table_tb:
@@ -490,7 +492,10 @@ class MeshApp:
             t, dt, t_ratio = read_tmp_file(name_of_tmp_file=os.path.join(self.mesh_results_folder, "mesh_res_t.txt"))
             p, dt, p_ratio = read_tmp_file(name_of_tmp_file=os.path.join(self.mesh_results_folder, "mesh_res_p.txt"))
             r, rt, r_ratio = read_tmp_file(name_of_tmp_file=os.path.join(self.mesh_results_folder, "mesh_res_r.txt"))
-            write_1d_mesh_hdf(outdir=self.mesh_results_folder, mesh_name="1x", t=t, p=p, r=r)
+            if self.hdf_file_path[-3:] == ".h5":
+                write_1d_mesh_hdf(outdir=self.mesh_results_folder, mesh_name="1x", t=t, p=p, r=r, type=".h5")
+            else:
+                write_1d_mesh_hdf(outdir=self.mesh_results_folder, mesh_name="1x", t=t, p=p, r=r, type=".hdf")
 
     def get_all_tabs_info(self):
         """ copy all tabs information to the ui dictionary. this step is done before saving the json file. """
@@ -578,6 +583,7 @@ class MeshApp:
         if mesh.is_valid():
             adj_mesh = mesh.resolve_mesh_segments().json_dict()
             legacy_mesh = mesh.build_legacy_mesh().json_dict()
+            mpl.pyplot.close("all")
             create_psi_mesh(adj_mesh, legacy_mesh, 't', self.mesh_results_folder, output_file_name="tmp_mesh_t.dat",
                             mesh_res_file_name="mesh_res_t.txt", show_plot=show_plot,
                             save_plot_path=self.mesh_results_folder,
@@ -604,6 +610,7 @@ class MeshApp:
         if mesh.is_valid():
             adj_mesh = mesh.resolve_mesh_segments().json_dict()  # adjusted mesh as a dictionary
             legacy_mesh = mesh.build_legacy_mesh().json_dict()  # legacy mesh as a dictionary
+            mpl.pyplot.close("all")
             create_psi_mesh(adj_mesh, legacy_mesh, 'p', self.mesh_results_folder, output_file_name="tmp_mesh_p.dat",
                             mesh_res_file_name="mesh_res_p.txt", show_plot=show_plot, save_plot=True,
                             save_plot_path=self.mesh_results_folder, plot_file_name="phi_mesh_spacing.png")
@@ -662,6 +669,7 @@ class MeshApp:
         if mesh.is_valid():
             adj_mesh = mesh.resolve_mesh_segments().json_dict()
             legacy_mesh = mesh.build_legacy_mesh().json_dict()
+            mpl.pyplot.close("all")
             create_psi_mesh(adj_mesh, legacy_mesh, 'r', self.mesh_results_folder, output_file_name="tmp_mesh_r.dat",
                             mesh_res_file_name="mesh_res_r.txt", show_plot=show_plot, save_plot=True,
                             save_plot_path=self.mesh_results_folder, plot_file_name="r_mesh_spacing.png")
@@ -751,8 +759,9 @@ class MeshApp:
                 self.patch_list.insert(self.box_num - 1, self.rect_data)
                 self.box_num = 0
                 self.redraw_box_submit = False
+                self.canvas.draw()
         else:
-            print("First click APPLY button to remove the box from image, then redraw the same box and click SUMBIT.")
+            print("First click apply button to remove the box from image, then redraw the same box and click submit.")
 
     def redraw_box_apply(self):
         """ Remove the txt box number and patch of box. """
@@ -778,6 +787,7 @@ class MeshApp:
                 current_box.remove()
                 self.patch_list.remove(current_box)
                 self.redraw_box_submit = True
+                self.canvas.draw()
         else:
             print("Please redraw the box and then click submit.")
 
@@ -801,14 +811,13 @@ class MeshApp:
 
                 # add a ds text box for step #2
                 tk.Label(self.leftFrame, text=label_box, relief=tk.RIDGE, bg='lightgray', bd=2). \
-                    grid(row=8 + len(self.ui_session.box_list), column=0, sticky=tk.NSEW)
-                self.ds_tab_array.append(tk.Entry(self.leftFrame, width=11, bg='white'))
-                self.var_ds_tab_array.append(tk.Entry(self.leftFrame, width=11, bg='white'))
+                    grid(row=9 + len(self.ui_session.box_list), column=0, sticky=tk.NSEW)
+                self.ds_tab_array.append(tk.Entry(self.leftFrame, width=10, bg='white'))
+                self.var_ds_tab_array.append(tk.Entry(self.leftFrame, width=10, bg='white'))
                 self.ds_tab_array[-1].insert(tk.END, '')
-                self.var_ds_tab_array[-1].insert(tk.END, '')
-                self.ds_tab_array[-1].grid(row=8 + len(self.ui_session.box_list), column=1, sticky=tk.NSEW)
-                self.var_ds_tab_array[-1].grid(row=8 + len(self.ui_session.box_list), column=2, sticky=tk.NSEW,
-                                               columnspan=2)
+                self.var_ds_tab_array[-1].insert(tk.END, str(self.ui_session.FG_RATIO))
+                self.ds_tab_array[-1].grid(row=9 + len(self.ui_session.box_list), column=1, sticky=tk.NSEW)
+                self.var_ds_tab_array[-1].grid(row=9 + len(self.ui_session.box_list), column=2, sticky=tk.NSEW)
 
                 # add a radial textbox
                 tk.Label(self.rightFrame, text=label_box, relief=tk.RIDGE, bg='lightgray', bd=2) \
@@ -816,7 +825,7 @@ class MeshApp:
                 cols = []
                 i = len(self.ui_session.box_list) - 1
                 for j in range(4):
-                    e = tk.Entry(self.rightFrame, width=5)
+                    e = tk.Entry(self.rightFrame, width=5, bg='white')
                     e.insert(tk.END, '')
                     e.grid(row=10 + len(self.ui_session.box_list), column=j + 1, sticky=tk.NSEW)
                     cols.append(e)
@@ -873,7 +882,7 @@ class MeshApp:
                 self.patch_list.remove(current_box)
 
                 # delete the lastest ds textbox and label
-                tk.Label(self.leftFrame, text="             ").grid(row=9 + len(self.ui_session.box_list),
+                tk.Label(self.leftFrame, text="             ").grid(row=10 + len(self.ui_session.box_list),
                                                                     column=0, sticky=tk.NSEW)
                 self.ds_tab_array[-1].destroy()
                 self.ds_tab_array.pop()
