@@ -14,7 +14,7 @@ class MeshGeneratorUI:
     def __init__(self):
         # main window.
         self.root = tk.Tk()
-        self.root.wm_title("Upload Magnetogram")  # title of the window.
+        self.root.wm_title("PSI Mesh Generator")  # title of the window.
 
         for ii in range(12):
             self.root.grid_columnconfigure(ii, weight=1)  # the text and entry frames column
@@ -29,9 +29,9 @@ class MeshGeneratorUI:
         self.save_folder_path = None
 
         # print instructions on window.
-        tk.Label(self.root, text="Step 1: Upload Magnetogram 2D hdf file, input path:").grid(row=0, column=0,
-                                                                                             sticky=tk.W,
-                                                                                             columnspan=2)
+        tk.Label(self.root, text="Step 1: Upload Magnetogram 2D hdf/h5 file, input path:").grid(row=0, column=0,
+                                                                                                sticky=tk.W,
+                                                                                                columnspan=2)
 
         tk.Label(self.root, text="Step 2: (Optional) Upload a json file constaining previous session mesh "
                                  "requirements, otherwise will start a new UI session. "). \
@@ -63,7 +63,7 @@ class MeshGeneratorUI:
         tk.Button(self.root, text='browse', command=self.find_dir).grid(row=8, column=4, sticky=tk.W)
 
         # skip interactive and open main ui window.
-        tk.Button(self.root, text="Skip interactive", command=self.skip_interactive). \
+        tk.Button(self.root, text="Generate mesh from json", command=self.skip_interactive). \
             grid(row=12, column=1, sticky=tk.NSEW)
         tk.Button(self.root, text="Mesh UI main window", command=self.main_app_window_activate). \
             grid(row=12, column=2, sticky=tk.NSEW)
@@ -82,8 +82,9 @@ class MeshGeneratorUI:
                                                                initialdir="/",
                                                                filetypes=[('hdf file', '.hdf'),
                                                                           ('h5 file', '.h5')])
-        self.upload_mag_path.delete("0", "end")
-        self.upload_mag_path.insert(tk.END, self.hdf_file_path)
+        if self.hdf_file_path != "":
+            self.upload_mag_path.delete("0", "end")
+            self.upload_mag_path.insert(tk.END, self.hdf_file_path)
 
     def find_path_json(self):
         """ json file browser function. """
@@ -94,8 +95,9 @@ class MeshGeneratorUI:
         else:
             self.json_file_path = tk.filedialog.askopenfilename(parent=self.root, title='Select a File',
                                                                 initialdir="/", filetypes=[('json file', '.json')])
-        self.upload_json_path.delete("0", "end")
-        self.upload_json_path.insert(tk.END, self.json_file_path)
+        if self.json_file_path != "":
+            self.upload_json_path.delete("0", "end")
+            self.upload_json_path.insert(tk.END, self.json_file_path)
 
     def find_dir(self):
         """ json file browser function. """
@@ -105,8 +107,10 @@ class MeshGeneratorUI:
         else:
             self.save_folder_path = tk.filedialog.askdirectory(parent=self.root, title='Select a Folder',
                                                                initialdir="/")
-        self.save_dir.delete("0", "end")
-        self.save_dir.insert(tk.END, self.save_folder_path)
+
+        if self.save_folder_path != "":
+            self.save_dir.delete("0", "end")
+            self.save_dir.insert(tk.END, self.save_folder_path)
 
     def get_save_dir_path(self):
         """ return the latest save dir path. """
